# Contributing

Want to contribute? Email mikekeith52@gmail.com with your ideas. Please also consider opening issues or feature requests using the Issues tab in GitHub. We could also use more example notebooks displayed in our [examples](https://scalecast-examples.readthedocs.io/en/latest/) webpage. If you fork the [scalecast-examples](https://github.com/mikekeith52/scalecast-examples) repository and submit a merge request with a good notebook that showcases scalecast, we will host it and give you credit.  